==> pointpos_api-0.0.16.tar.gz: lib/model/role_permission.dart <==
import 'package:jaguar_serializer/jaguar_serializer.dart';


part 'role_permission.jser.dart';

class RolePermission {
  
  @Alias('id', isNullable: false,  )
  final String id;
  
  @Alias('name', isNullable: false,  )
  final String name;
  
  @Alias('isPrimitive', isNullable: false,  )
  final bool isPrimitive;
  
  @Alias('isPublic', isNullable: false,  )
  final bool isPublic;
  
  @Alias('isPinRequired', isNullable: false,  )
  final bool isPinRequired;
  
  @Alias('platform', isNullable: false,
          
  )
  final String platform;
  //enum platformEnum {  WEB_DESKTOP,  MOBILE_APPS,  THIRD_PARTY,  };
  @Alias('permissionIds', isNullable: false,  )
  final List<String> permissionIds;
  
  @Alias('createdAt', isNullable: false,  )
  final DateTime createdAt;
  
  @Alias('createdBy', isNullable: false,  )
  final String createdBy;
  
  @Alias('updatedAt', isNullable: false,  )
  final DateTime updatedAt;
  
  @Alias('updatedBy', isNullable: false,  )
  final String updatedBy;
  

  RolePermission(
      

{
     this.id = null,  
    
     this.name = null,   this.isPrimitive = true,  
     this.isPublic = false,  
     this.isPinRequired = false,  
     this.platform = null,  
     this.permissionIds = const [],  
     this.createdAt = null,  
     this.createdBy = null,  
     this.updatedAt = null,  
     this.updatedBy = null 
    
    }
  );

  @override
  String toString() {
    return 'RolePermission[id=$id, name=$name, isPrimitive=$isPrimitive, isPublic=$isPublic, isPinRequired=$isPinRequired, platform=$platform, permissionIds=$permissionIds, createdAt=$createdAt, createdBy=$createdBy, updatedAt=$updatedAt, updatedBy=$updatedBy, ]';
  }
}

@GenSerializer(nullableFields: true)
class RolePermissionSerializer extends Serializer<RolePermission> with _$RolePermissionSerializer {

}

==> pointpos_api-0.2.0.tar.gz: lib/model/role_permission.dart <==
import 'package:jaguar_serializer/jaguar_serializer.dart';


part 'role_permission.jser.dart';

class RolePermission {
  
  @Alias('id', isNullable: false,  )
  final String id;
  
  @Alias('name', isNullable: false,  )
  final String name;
  
  @Alias('isPrimitive', isNullable: false,  )
  final bool isPrimitive;
  
  @Alias('isPublic', isNullable: false,  )
  final bool isPublic;
  
  @Alias('isPinRequired', isNullable: false,  )
  final bool isPinRequired;
  
  @Alias('platform', isNullable: false,
          
  )
  final String platform;
  //enum platformEnum {  WEB_DESKTOP,  MOBILE_APPS,  THIRD_PARTY,  };
  @Alias('permissionIds', isNullable: false,  )
  final List<String> permissionIds;
  
  @Alias('createdAt', isNullable: false,  )
  final DateTime createdAt;
  
  @Alias('createdBy', isNullable: false,  )
  final String createdBy;
  
  @Alias('updatedAt', isNullable: false,  )
  final DateTime updatedAt;
  
  @Alias('updatedBy', isNullable: false,  )
  final String updatedBy;
  
  @Alias('deleted', isNullable: false,  )
  final bool deleted;
  

  RolePermission(
      

{
     this.id = null,  
    
     this.name = null,   this.isPrimitive = true,  
     this.isPublic = false,  
     this.isPinRequired = false,  
     this.platform = null,  
     this.permissionIds = const [],  
     this.createdAt = null,  
     this.createdBy = null,  
     this.updatedAt = null,  
     this.updatedBy = null,  
     this.deleted = null 
    
    }
  );

  @override
  String toString() {
    return 'RolePermission[id=$id, name=$name, isPrimitive=$isPrimitive, isPublic=$isPublic, isPinRequired=$isPinRequired, platform=$platform, permissionIds=$permissionIds, createdAt=$createdAt, createdBy=$createdBy, updatedAt=$updatedAt, updatedBy=$updatedBy, deleted=$deleted, ]';
  }
}

@GenSerializer(nullableFields: true)
class RolePermissionSerializer extends Serializer<RolePermission> with _$RolePermissionSerializer {

}
